@@ -121,8 +121,8 @@ setConstructorS3("NPVI", function(obs=matrix(nrow=0, ncol=3, dimnames=list(NULL,
   extend(Object(), "NPVI",
          .obs=obs, #.flavor=flavor,
          .Xq=Xq, .Yq=Yq,
-         .g=NULL, .mu=NULL, .theta=NULL, .theta0=NULL, .weightsW=rep(1, nrow(obs)), 
-         .gtab=NULL, .mutab=NULL, .thetatab=NULL, .theta0tab=NULL,
+         .g=NULL, .mu=NULL, .muAux=NULL, .theta=NULL, .theta0=NULL, .weightsW=rep(1, nrow(obs)), 
+         .gtab=NULL, .mutab=NULL, .muAuxtab=NULL, .thetatab=NULL, .theta0tab=NULL,
          .sigma2=NA, .psi=NA, .psi.sd=NA, .psiPn=NA, .psiPn.sd=NA,
          .gmin=gmin, .gmax=gmax, .mumin=mumin, .mumax=mumax,
          .thetamin=thetamin, .thetamax=thetamax,
