@@ -1,3 +1,7 @@
+source("http://callr.org/install#knitr") ## to build package vignette
+source("http://callr.org/install#R.utils")
+install.packages("geometry")
+
 ## for SuperLearning
 install.packages("SuperLearner")
 install.packages("gam")
@@ -7,4 +11,4 @@ install.packages("e1071")
 install.packages("polspline")
 install.packages("quadprog")
 install.packages("randomForest")
-install.packages("sgeostat")
+
